@@ -2,7 +2,7 @@
 #' each list member.
 #'
 #' @param .data \code{list}
-#' @param expr An expression that is evaluated for each item
+#' @param expr A lambda expression
 #' @name list.iter
 #' @export
 #' @examples
@@ -14,7 +14,6 @@
 #' list.iter(x,cat(str(.)))
 #' }
 list.iter <- function(.data,expr) {
-  expr <- substitute(expr)
-  list.map.internal(.data,expr)
+  list.map.internal(.data,substitute(expr))
   invisible()
 }
